//
//  ViewController.swift
//  AccelerometerBsp
//
//  Created by Christian Bleske on 14.12.14.
//  Copyright (c) 2014 Christian Bleske. All rights reserved.
//

import UIKit
import CoreMotion

class ViewController: UIViewController {
    
    var uiView : UIView?
    var uiDynamicAnimator:UIDynamicAnimator? = nil;
    let uiGravityBehavior = UIGravityBehavior()
    let uiCollisionBehavior = UICollisionBehavior()
    let cmMotionManager = CMMotionManager()
    let nsOperationQueue = NSOperationQueue()

    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        self.view.backgroundColor = UIColor.greenColor()
        addView(CGRectMake(150, 150, 50, 50))
        initBehavior()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func initBehavior() {
        uiDynamicAnimator = UIDynamicAnimator(referenceView:self.view);
        
        uiGravityBehavior.addItem(uiView!);
        uiGravityBehavior.gravityDirection = CGVectorMake(0, 0.8)
        uiDynamicAnimator?.addBehavior(uiGravityBehavior);
        
        uiCollisionBehavior.addItem(uiView!)
        uiCollisionBehavior.translatesReferenceBoundsIntoBoundary = true
        uiDynamicAnimator?.addBehavior(uiCollisionBehavior)
    }
    
    func addView(location: CGRect) {
        let newView = UIView(frame: location)
        
        newView.backgroundColor = UIColor.blackColor()
        
        view.insertSubview(newView, atIndex: 0)
        uiView = newView
    }
    
    override func viewDidAppear(animated: Bool) {
        cmMotionManager.startDeviceMotionUpdatesToQueue(nsOperationQueue,
            withHandler: cmAccelerometerHandler)
    }

    
    func cmAccelerometerHandler(motion: CMDeviceMotion?, error: NSError?) {
        if (error != nil) {
            NSLog("\(error)")
        }
        
        let gravity : CMAcceleration = motion!.gravity
        let x = CGFloat(gravity.x)
        let y = CGFloat(gravity.y)
        let cgPoint = CGPointMake(x,y)
        let v = CGVectorMake(cgPoint.x, 0 - cgPoint.y)
        uiGravityBehavior.gravityDirection = v
    }

    override func viewWillDisappear(animated: Bool) {
        cmMotionManager.stopDeviceMotionUpdates()
    }


}

