//
//  ViewController.swift
//  AudioRecorderBsp
//
//  Created by Christian Bleske on 23.02.15.
//  Copyright (c) 2015 Christian Bleske. All rights reserved.
//

import UIKit
import AVFoundation
import MediaPlayer

class ViewController: UIViewController, AVAudioPlayerDelegate, AVAudioRecorderDelegate {

    var avAudioPlayer: AVAudioPlayer?
    var avAudioRecorder: AVAudioRecorder?
    
    @IBOutlet var btnRecord: UIButton!
    @IBOutlet var btnStop: UIButton!
    @IBOutlet var btnPlay: UIButton!
    
    @IBOutlet var uiLabelStatus: UILabel!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        btnPlay.enabled = false
        btnStop.enabled = true

        avAudioPlayer?.delegate = self;
        avAudioRecorder?.delegate = self;
        
        let dirPaths =
        NSSearchPathForDirectoriesInDomains(.DocumentDirectory,
            .UserDomainMask, true)
        let docsDir = dirPaths[0] as String
        let soundFilePath = docsDir + ("/sound.caf")

        let soundFileURL = NSURL(fileURLWithPath: soundFilePath)
        let recordSettings =
        [AVEncoderAudioQualityKey: AVAudioQuality.Min.rawValue,
            AVEncoderBitRateKey: 16,
            AVNumberOfChannelsKey: 2,
            AVSampleRateKey: 44100.0]
        
        
        let audioSession = AVAudioSession.sharedInstance()
        
        do {
            try audioSession.setCategory(AVAudioSessionCategoryPlayAndRecord)
        } catch {
            print("Fehler bei der Initialisierung")
        }

        do {
            try avAudioRecorder = AVAudioRecorder(URL: soundFileURL, settings: recordSettings as! [String : AnyObject])
            avAudioRecorder?.prepareToRecord()
        } catch {
            print("Fehler bei der Initialisierung")
        }
        
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBAction func btnRecord_Pressed(sender: AnyObject) {
        if avAudioRecorder?.recording == false {
            btnPlay.enabled = false
            btnStop.enabled = true
            avAudioRecorder?.record()
            uiLabelStatus.text = "Aufnahme läuft..."
        }
    }

    @IBAction func btnStop_Pressed(sender: AnyObject) {
        btnStop.enabled = false
        btnPlay.enabled = true
        btnRecord.enabled = true
        
        if avAudioRecorder?.recording == true {
            avAudioRecorder?.stop()
            uiLabelStatus.text = "Aufnahme beendet..."
        } else {
            avAudioPlayer?.stop()
            uiLabelStatus.text = "Wiedergabe beendet..."
        }
    }
    
    @IBAction func btnPlay_Pressed(sender: AnyObject) {
        if avAudioRecorder?.recording == false {
            btnStop.enabled = true
            btnRecord.enabled = false
            uiLabelStatus.text = "Wiedergabe läuft..."
            
            do {
                avAudioPlayer = try AVAudioPlayer(contentsOfURL: (avAudioRecorder?.url)!)
                avAudioPlayer?.play()
            } catch {
               print("Fehler bei der Wiedergabe!")
            }
        }
    }
    
    func audioPlayerDidFinishPlaying(player: AVAudioPlayer,
        successfully flag: Bool) {
            print("Wiedergabe beendet...")
            uiLabelStatus.text = "Wiedergabe beendet..."
    }
    
    func audioPlayerDecodeErrorDidOccur(player: AVAudioPlayer,
        error: NSError?) {
        print("Ein Fehler ist während der Wiedergabe aufgetreten...")
    }
    
    func audioRecorderDidFinishRecording(recorder: AVAudioRecorder, successfully flag: Bool) {
        print("Aufnahme beendet...")
        uiLabelStatus.text = "Aufnahme beendet..."
    }
    
    func audioRecorderEncodeErrorDidOccur(recorder: AVAudioRecorder, error: NSError?) {
        print("Ein Fehler ist während der Aufnahme aufgetreten...")
    }
}

