//
//  MasterViewController.swift
//  Passwortverwaltung
//
//  Created by Christian Bleske on 29.11.14.
//  Copyright (c) 2014 Christian Bleske. All rights reserved.
//

import UIKit
import CoreData
import LocalAuthentication

class MasterViewController: UITableViewController {

    var managedObjectContext: NSManagedObjectContext? = nil
    var passworte = NSMutableArray()

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        self.navigationItem.leftBarButtonItem = self.editButtonItem()
        self.navigationItem.leftBarButtonItem?.title = NSLocalizedString("MVC_leftBarButtonItem", comment: "-")
        authenticate();
    }
    
    func authenticate() {
        let laContext = LAContext()
        var error: NSError?
        
        if laContext.canEvaluatePolicy(LAPolicy.DeviceOwnerAuthenticationWithBiometrics, error: &error) {
            let reason =  NSLocalizedString("Msg_Reason_TouchID", comment: "-") //"Überprüfung mit TouchID"
            laContext.evaluatePolicy(LAPolicy.DeviceOwnerAuthenticationWithBiometrics, localizedReason: reason, reply: {(succes: Bool, error: NSError?) -> Void in
                    if succes {
                        self.showAlertViewWithTitle(NSLocalizedString("Msg_Title", comment: "-"),message: NSLocalizedString("Msg_TouchID_success", comment: "-"))//"Prüfung mit TouchID erfolgreich!")
                    }
                    else {
                        self.showAlertViewWithTitle(NSLocalizedString("Msg_Title", comment: "-"),message: NSLocalizedString("Msg_TouchID_failed", comment: "-"))//"Prüfung mit TouchID nicht erfolgreich!")
                        self.tableView.allowsSelection = false
                    }
            })
        }
            
        else {
            showAlertViewWithTitle(NSLocalizedString("Msg_Title", comment: "-"),message: NSLocalizedString("Msg_TouchID_NA", comment: "-"))//"TouchID nicht verfügbar!")
        }
        
    }

    func showAlertViewWithTitle(title:String, message:String) {
        
        let alertController = UIAlertController(title: title, message: message, preferredStyle: .Alert)
        
        
        let OKAction = UIAlertAction(title: "OK", style: .Default) { (action) in
            // ...
        }
        
        alertController.addAction(OKAction)
        
        self.presentViewController(alertController, animated: true) {
            // ...
        }
        
    }
    
    override func viewWillAppear(animated: Bool) {
        loadData()
    }
    
    func writeData() {
        do {
            try managedObjectContext?.save()
        } catch _ {
        }
    }
    
    func loadData() {
        passworte.removeAllObjects()
        let fetchRequest = NSFetchRequest(entityName: "Passwort")
        
        var fetchResults:[AnyObject]?
        do {
            fetchResults = try managedObjectContext!.executeFetchRequest(fetchRequest) as! [Passwort]
            for passwort: Passwort in fetchResults as! [Passwort]{
                print(passwort.name + " " + passwort.passwort)
                passworte.addObject(passwort)
            }
            self.tableView.reloadData();
        } catch {
            if (fetchResults!.count <= 0) {
                showAlertViewWithTitle("Hinweis", message: "Datensatz nicht gefunden!")
            }
        }
    }


    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Segues

    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if segue.identifier == "showDetail" {
            if let indexPath = self.tableView.indexPathForSelectedRow {
                let pwd = passworte[indexPath.row] as! Passwort
                (segue.destinationViewController as! DetailViewController).detailItem = pwd
            }
        }
    }
    
    // MARK: - Table View

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return passworte.count
    }

    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell", forIndexPath: indexPath) as UITableViewCell
        
        let pwd = passworte[indexPath.row] as! Passwort
        cell.textLabel?.text = pwd.name
        return cell
        
    }

    override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        return true
    }
    
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            print( indexPath )
            let pwd = passworte[indexPath.row] as! NSManagedObject
            self.managedObjectContext?.deleteObject(pwd)
            writeData()
            loadData()
            self.tableView.reloadData();
        }
    }

}

